word2tei
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

This file will become your README and also the index of your
documentation.

## Install

``` sh
pip install word2tei
```

## How to use

Fill me in please! Don’t forget code examples:

``` python
input_path = "data/input.docx"
output_path = "data/output.xml"
template_path = "data/template.xml"
convert_docx_to_tei(input_path, output_path, template_path)
```
